@@ -53,7 +53,9 @@
    #:gcm #:etm #:eax
 
    ;; KDFs
+   #:list-all-kdfs
    #:pbkdf1 #:pbkdf2 #:hmac-kdf #:scrypt-kdf #:argon2i #:argon2d
+   #:bcrypt #:bcrypt-pbkdf
    #:make-kdf #:derive-key
 
    ;; KDF convenience functions
@@ -62,11 +64,13 @@
    #:pbkdf2-check-password
 
    ;; public-key encryption operations
+   #:list-all-key-pair-kinds
    #:make-public-key #:destructure-public-key
    #:make-private-key #:destructure-private-key
    #:generate-key-pair
    #:make-signature #:destructure-signature
    #:make-message #:destructure-message
+   #:generate-signature-nonce
    #:sign-message #:verify-signature
    #:encrypt-message #:decrypt-message
    #:diffie-hellman
@@ -74,14 +78,31 @@
    ;; public-key encryption/signature padding
    #:oaep-encode #:oaep-decode #:pss-encode #:pss-verify
 
+   ;; public/private keys
+   #:curve25519-public-key #:curve25519-private-key
+   #:curve448-public-key #:curve448-private-key
+   #:dsa-public-key #:dsa-private-key
+   #:ed25519-public-key #:ed25519-private-key
+   #:ed448-public-key #:ed448-private-key
+   #:elgamal-public-key #:elgamal-private-key
+   #:rsa-public-key #:rsa-private-key
+   #:secp256k1-public-key #:secp256k1-private-key
+   #:secp256r1-public-key #:secp256r1-private-key
+   #:secp384r1-public-key #:secp384r1-private-key
+   #:secp521r1-public-key #:secp521r1-private-key
+
    ;; public-key slot readers
    #:dsa-key-p #:dsa-key-q #:dsa-key-g #:dsa-key-y #:dsa-key-x
    #:elgamal-key-p #:elgamal-key-g #:elgamal-key-y #:elgamal-key-x
-   #:rsa-key-modulus #:rsa-key-exponent
+   #:rsa-key-modulus #:rsa-key-exponent #:rsa-key-prime-p #:rsa-key-prime-q
    #:ed25519-key-x #:ed25519-key-y
    #:ed448-key-x #:ed448-key-y
    #:curve25519-key-x #:curve25519-key-y
    #:curve448-key-x #:curve448-key-y
+   #:secp256k1-key-x #:secp256k1-key-y
+   #:secp256r1-key-x #:secp256r1-key-y
+   #:secp384r1-key-x #:secp384r1-key-y
+   #:secp521r1-key-x #:secp521r1-key-y
 
    ;; pseudo-random number generators
    #:list-all-prngs #:make-prng #:random-data #:read-os-random-seed
